// pages/book/book.js
// 获取全局的应用实例
const app = getApp();

// 引入utils全局函数
var dou = require('../../utils/util.js');

Page({
  data: {
    isDefault: false,
  },
 
  onShow: function () {
    var that = this;
    
    // 判断是否登录
    dou.checkLoginState()
   
    that.provinceList()
  },
 
  onLoad: function(options) {
    var that = this
    
    that.setData({
      title: app.title.user_contact_add
    })
   
    // 设置转发标题缓存
    wx.setStorageSync('shareTitle', app.title.user_contact_add)
    
    // 显示转发按钮
    dou.showShareMenu()
   
    wx.request({
      url: app.mp_url + 'databox.php?rec=common',
      success: function(res) {
        that.setData({
          lang: res.data.lang,
          site: res.data.site,
          open: res.data.open
        })
      },
    })
   
    if (options.from) {
      that.setData({
        from: options.from
      })
    }
  },
 
  contactAction: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=contact&act=insert',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        name: e.detail.value.name,
        telphone: e.detail.value.telphone,
        card: e.detail.value.card || '',
        province: that.data.selectedProvince || '',
        city: that.data.selectedCity || '',
        district: that.data.selectedDistrict || '',
        address: e.detail.value.address,
        tag: e.detail.value.tag,
        default: e.detail.value.default
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          if (that.data.from == 'checkout') {
            wx.redirectTo({
              url: '/pages/order/checkout?contact_id=' + res.data.contact_id
            });
          } else {
            dou.douPageTo('/pages/user/contact')
          }
        }
      }
    })
  },
 
  // 省份列表
  provinceList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'province'
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            province_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 省份选择
  handleProvinceChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedProvince: this.data.province_list[index].name,
      selectedCity: '',
      selectedDistrict: ''
    })
   
    this.cityList()
  },
 
  // 城市列表
  cityList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'city',
        parent: that.data.selectedProvince
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            city_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 城市选择
  handleCityChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedCity: this.data.city_list[index].name,
      selectedDistrict: '',
    })
   
    this.districtList()
  },
 
  // 区县列表
  districtList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'district',
        parent: that.data.selectedCity
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            district_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 区县选择
  handleDistrictChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedDistrict: this.data.district_list[index].name
    })
  },
 
  // 监听复选框变化
  onCheckboxChange(e) {
    const isChecked = e.detail.value.includes('1'); // 检查是否选中
    this.setData({
      isDefault: isChecked
    });
  },
 
  // 返回到指定路径的页面
  douPageTo: function(e) {
    dou.douPageTo(e.currentTarget.dataset.url)
  },
 
  // 非tabBar的页面，可以带参数
  douNavigateTo: function(e) {
    var url = e.currentTarget.dataset.url;
    wx.navigateTo({
      url: url
    })
  }

})