// pages/book/book.js
// 获取全局的应用实例
const app = getApp();

// 引入utils全局函数
var dou = require('../../utils/util.js');

Page({
  data: {
    contact: []
  },
 
  onShow: function () {
    var that = this;
    
    // 判断是否登录
    dou.checkLoginState()
  },
 
  onLoad: function(options) {
    var that = this
    
    that.setData({
      title: app.title.user_contact_edit
    })
   
    // 设置转发标题缓存
    wx.setStorageSync('shareTitle', app.title.user_contact_edit)
    
    // 显示转发按钮
    dou.showShareMenu()
   
    wx.request({
      url: app.mp_url + 'databox.php?rec=common',
      success: function(res) {
        that.setData({
          lang: res.data.lang,
          site: res.data.site,
          open: res.data.open
        })
      },
    })
   
    wx.request({
      url: app.mp_url + 'user.php?rec=contact&act=edit',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        id: options.id
      },
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key')
      },
      success: function(res) {
        that.setData({
          contact: res.data.contact
        })
        
        that.setData({
          selectedProvince: res.data.contact.province || ''
        })
        that.provinceList()
       
        if (res.data.contact.city) {
          that.setData({
            selectedCity: res.data.contact.city
          })
          that.cityList()
        }
       
        if (res.data.contact.district) {
          that.setData({
            selectedDistrict: res.data.contact.district
          })
          that.districtList()
        }
      }
    })
   
    if (options.from) {
      that.setData({
        from: options.from
      })
    }
  },
 
  contactAction: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=contact&act=update',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        name: e.detail.value.name,
        telphone: e.detail.value.telphone,
        card: e.detail.value.card,
        province: that.data.selectedProvince || '',
        city: that.data.selectedCity || '',
        district: that.data.selectedDistrict || '',
        address: e.detail.value.address,
        tag: e.detail.value.tag,
        id: that.data.contact.id
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          if (that.data.from == 'checkout') {
            wx.redirectTo({
              url: '/pages/order/checkout?contact_id=' + that.data.contact.id
            });
          } else {
            dou.douPageTo('/pages/user/contact')
          }
        }
      }
    })
  },
 
  // 省份列表
  provinceList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'province',
        current: that.data.selectedProvince || ''
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            province_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 省份选择
  handleProvinceChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedProvince: this.data.province_list[index].name,
      selectedCity: '',
      selectedDistrict: ''
    })
   
    this.cityList()
  },
 
  // 城市列表
  cityList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'city',
        parent: that.data.selectedProvince,
        current: that.data.selectedCity || ''
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            city_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 城市选择
  handleCityChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedCity: this.data.city_list[index].name,
      selectedDistrict: '',
    })
   
    this.districtList()
  },
 
  // 区县列表
  districtList: function (e) {
    var that = this
    
    // 未登录时重新载入当前页面
    dou.checkLoginState('action', '/pages/user/user')
   
    wx.request({
      url: app.mp_url + 'user.php?rec=area',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        type: 'district',
        parent: that.data.selectedCity,
        current: that.data.selectedDistrict || ''
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.wrong) {
          dou.douMsg(res.data.wrong)
        } else {
          that.setData({
            district_list: res.data.area_list
          })
        }
      }
    })
  },
  
  // 区县选择
  handleDistrictChange(e) {
    const index = e.detail.value
    
    this.setData({
      selectedDistrict: this.data.district_list[index].name
    })
  },
 
  // 返回到指定路径的页面
  douPageTo: function(e) {
    dou.douPageTo(e.currentTarget.dataset.url)
  },
 
  // 非tabBar的页面，可以带参数
  douNavigateTo: function(e) {
    var url = e.currentTarget.dataset.url;
    wx.navigateTo({
      url: url
    })
  }

})